@@ -1,19 +1,53 @@
 ######################################################################################
-# print.tdmRegre
+# print.TDMregressor     and print.tdmRegre
 #
-#'   Print an overview for a \code{tdmRegre} object.
+#'   Print an overview for a \code{\link{TDMregressor}} or \code{tdmRegre} object.
 #'
-#'   @method print tdmRegre
-#'   @param x  return value from a prior call to \code{\link{tdmRegress}}, an object of class \code{tdmRegre}.
+#'   @method print TDMregressor
+#'   @param x  an object of class \code{tdmRegre}, as returned from a prior call to \code{\link{tdmRegress}}, \cr
+#'          or  an object of class \code{\link{TDMregressor}}, as returned from a prior call to \code{\link{tdmRegressLoop}}.
 #'   @param ... e.g. 'type'    which information to print:
 #'      \describe{
 #'      \item{\code{"overview"}}{ (def.) RMAE on training/test set, number of records, see \code{\link{tdmRegressSummary}}}
 #'      \item{\code{"..."}}{ ... other choices, TODO ...}
 #'      \item{\code{"?"}}{ help on this method}
 #'      }
+#' @seealso   \code{\link{tdmRegress}}, \code{\link{TDMregressor}}
+#' @export
+######################################################################################
+print.TDMregressor <- function(x,...) {
+  internalPrintR <- function(result,type) {
+    opts = result$lastRes$opts;
+    opts$VERBOSE = 2;
+    z <- switch(type
+      , "overview"= { tdmRegressSummary(result,opts);
+              cat("\nUse > print(result,type=\"?\") and > result$lastRes   for more info on TDMregressor object result."); 
+              cat("\nUse > names(result) and > result[]   to see all names and all contents (may be long) of object result."); 
+              1;  # a value for z
+              }
+      , "?"={cat("Help for print(<TDMregressor>,type=t). Possible values for 't' are:\n"
+               ,"\"overview\": see tdmRegressSummary\n"
+               ,"\"?\" : display this help message\n"
+               ); 1;}   # a value for z
+      , "invalid type"
+      );
+    if (z[1]=="invalid type") warning("Invalid type = ",type,". Allowed types are: overview, ?.");
+    cat("\n");
+  }
+
+  vaarg <- list(...)
+  #alternative: vavalues <- c(...)
+
+  if (is.null(vaarg$type)) vaarg$type="overview";
+  internalPrintR(x,vaarg$type);
+}
+
+######################################################################################
+# print.tdmRegre
+# Print an overview for a \code{tdmRegre} object.
 #'
-#' @seealso   \code{\link{tdmRegress}}, \code{\link{print.TDMregressor}}
-#' @author Wolfgang Konen, FHK, Oct'2011 - Dec'2011
+#' @rdname print.TDMregressor
+#' @method print tdmRegre
 #' @export
 ######################################################################################
 print.tdmRegre <- function(x,...) {
@@ -22,7 +56,7 @@ print.tdmRegre <- function(x,...) {
     opts$VERBOSE = 2;
     z <- switch(type
       , "overview"= {show.tdmRegre(res);
-              cat("\nUse print(res,type=\"?\") for more info on tdmRegre object res.\n");
+              cat("\nUse < print(res,type=\"?\")   for more info on tdmRegre object res.\n");
               1;    # a value for z
               }
       , "?"={cat("Help for print(<tdmRegre>,type=t). Possible values for 't' are:\n"
@@ -49,44 +83,3 @@ show.tdmRegre <- function(res) {
                       nrow(res$d_train),nrow(res$d_test)));
 }
 
-######################################################################################
-# print.TDMregressor
-#
-#'   Print an overview for a \code{TDMregressor} object.
-#'
-#'   @method print TDMregressor
-#'   @param x  return value from a prior call to \code{\link{tdmRegressLoop}}, an object of class \code{TDMregressor}.
-#'   @param ... e.g. 'type'    which information to print:
-#'      \describe{
-#'      \item{\code{"overview"}}{ (def.) RMAE on training/test set, number of records, see \code{\link{tdmRegressSummary}}}
-#'      \item{\code{"..."}}{ ... other choices, TODO ...}
-#'      }
-#' @seealso   \code{\link{tdmRegressLoop}}, \code{\link{print.tdmRegre}}
-#' @export
-######################################################################################
-print.TDMregressor <- function(x,...) {
-  internalPrintR <- function(result,type) {
-    opts = result$lastRes$opts;
-    opts$VERBOSE = 2;
-    z <- switch(type
-      , "overview"= { tdmRegressSummary(result,opts);
-              cat("\nUse > print(result,type=\"?\") and > result$lastRes   for more info on TDMregressor object result."); 
-              1;  # a value for z
-              }
-      , "?"={cat("Help for print(<TDMregressor>,type=t). Possible values for 't' are:\n"
-               ,"\"overview\": see tdmRegressSummary\n"
-               ,"\"?\" : display this help message\n"
-               ); 1;}   # a value for z
-      , "invalid type"
-      );
-    if (z[1]=="invalid type") warning("Invalid type = ",type,". Allowed types are: overview, ?.");
-    cat("\n");
-  }
-
-  vaarg <- list(...)
-  #alternative: vavalues <- c(...)
-
-  if (is.null(vaarg$type)) vaarg$type="overview";
-  internalPrintR(x,vaarg$type);
-}
-
